pub enum ResizeParameter {
Auto,
Cells(u32),
Pixels(u32),
WindowPercent(u32),
}Expand description
Unit to specify a dimension to resize the graphic.
Variants
Auto
Dimension is computed from the original graphic dimensions.
Cells(u32)
Size is specified in number of grid cells.
Pixels(u32)
Size is specified in number pixels.
WindowPercent(u32)
Size is specified in a percent of the window.